@@ -21,7 +21,6 @@
 
 #include <QPair>
 #include <QMap>
-#include <KDebug>
 #include "Global.h"
 #include <lancelot/lancelot.h>
 
@@ -159,7 +158,7 @@ public:
 
             QSizeF size;
 
-            foreach (Qt::SizeHint which, sizeHintCache.keys()) {
+            foreach (const Qt::SizeHint &which, sizeHintCache.keys()) {
                 size = item->effectiveSizeHint(which);
                 size.scale(
                     1 / qMin(scaled.width(), qreal(1.0)),
