@@ -381,9 +381,9 @@ void MicroBlog::dataUpdated(const QString& source, const Plasma::DataEngine::Dat
 
         //add the newbies
         int newCount = 0;
-        uint maxId = m_lastTweet;
+        qulonglong maxId = m_lastTweet;
         foreach (const QString &id, data.keys()) {
-            uint i = id.toUInt();
+            qulonglong i = id.toULongLong();
             //kDebug() << i << m_lastTweet;
             if (i > m_lastTweet) {
                 newCount++;
@@ -464,7 +464,7 @@ void MicroBlog::showTweets()
     // Add more tweetWidgets if there are not enough
 
     if (m_tweetMap.count() > m_historySize) {
-        QMap<uint, Plasma::DataEngine::Data>::iterator it = m_tweetMap.begin();
+        QMap<qulonglong, Plasma::DataEngine::Data>::iterator it = m_tweetMap.begin();
         while (it != m_tweetMap.end() && m_tweetMap.count() > m_historySize) {
             it = m_tweetMap.erase(it);
         }
@@ -521,7 +521,7 @@ void MicroBlog::showTweets()
     }
 
     int i = 0;
-    QMap<uint, Plasma::DataEngine::Data>::iterator it = m_tweetMap.end();
+    QMap<qulonglong, Plasma::DataEngine::Data>::iterator it = m_tweetMap.end();
     while (it != m_tweetMap.begin()) {
         Plasma::DataEngine::Data &tweetData = *(--it);
         QString user = tweetData.value("User").toString();
@@ -548,9 +548,11 @@ void MicroBlog::showTweets()
         }
 
         QLocale english(QLocale::English, QLocale::UnitedStates);
+        QDateTime dt = english.toDateTime(tweetData.value( "Date" ).toString(), "ddd MMM dd HH:mm:ss +0000 yyyy");
+        dt.setTimeSpec(Qt::UTC);
         QString html = "<table cellspacing='0' spacing='5' width='100%'>";
         html += QString("<tr height='1em'><td align='left' width='1%'><font color='%2'>%1</font></td><td align='right' width='auto'><p align='right'><font color='%2'>%3%4</font></p></td></tr></table>").arg( user).arg(m_colorScheme->foreground(KColorScheme::InactiveText).color().name())
-                .arg(timeDescription( english.toDateTime(tweetData.value( "Date" ).toString(), "ddd MMM dd HH:mm:ss +0000 yyyy") )).arg( sourceString);
+                .arg(timeDescription( dt )).arg( sourceString);
         QString status = tweetData.value( "Status" ).toString();
 
         status.replace(QRegExp("((http|https)://[^\\s<>'\"]+[^!,\\.\\s<>'\"\\]])"), "<a href='\\1'>\\1</a>");
